DEFAULT_TAGS = {
    'Key': 'Solution',
    'Value': 'DataMeshUtils'
}

DOMAIN_TAG_KEY = 'Domain'
DATA_PRODUCT_TAG_KEY = 'DataProduct'
DATA_MESH_MANAGER_ROLENAME = 'DataMeshManager'
DATA_MESH_ADMIN_PRODUCER_ROLENAME = 'DataMeshAdminProducer'
DATA_MESH_ADMIN_CONSUMER_ROLENAME = 'DataMeshAdminConsumer'
DATA_MESH_READONLY_ROLENAME = 'DataMeshAdminReadOnly'
DATA_MESH_PRODUCER_ROLENAME = 'DataMeshProducer'
DATA_MESH_CONSUMER_ROLENAME = 'DataMeshConsumer'
DATA_MESH_IAM_PATH = '/AwsDataMesh/'
PRODUCER_POLICY_NAME = 'DataMeshProducerAccess'
CONSUMER_POLICY_NAME = 'DataMeshConsumerAccess'
SUBSCRIPTIONS_TRACKER_TABLE = 'AwsDataMeshSubscriptions'
MESH = 'Mesh'
PRODUCER = 'Producer'
CONSUMER = 'Consumer'
PRODUCER_ADMIN = 'ProducerAdmin'
CONSUMER_ADMIN = 'ConsumerAdmin'
BUCKET_POLICY_STATEMENT_SID = 'AwsDataMeshUtilsBucketPolicyStatement'
